@@ -20,12 +20,12 @@
 #
 #######################################################
 
-package CSVArrayImporter;
+package Ftree::DataParsers::ArrayImporters::CSVArrayImporter;
 use strict;
 use warnings;
-use version; our $VERSION = qv('2.3.31');
+use version; our $VERSION = qv('2.3.32');
 use Params::Validate qw(:all);
-use CGI::Carp qw(fatalsToBrowser);
+# use CGI::Carp qw(fatalsToBrowser);
 
 sub new {
     my ($classname, $file_name, $encoding) = @_;
