@@ -20,16 +20,16 @@
 #
 #######################################################
 
-package ExcelFormat;
+package Ftree::DataParsers::ExcelFormat;
 use strict;
 use warnings;
-use version; our $VERSION = qv('2.3.31');
+use version; our $VERSION = qv('2.3.32');
 
 use Spreadsheet::ParseExcel;
 use Ftree::DataParsers::ExtendedSimonWardFormat
   ;    # for getting pictures. Temporal solution
 use Ftree::FamilyTreeData;
-use CGI::Carp qw(fatalsToBrowser);
+# use CGI::Carp qw(fatalsToBrowser);
 use Encode qw(decode);
 
 sub createFamilyTreeDataFromFile {
@@ -37,7 +37,7 @@ sub createFamilyTreeDataFromFile {
     my $file_name = $config_->{file_name}
       or die "No file_name is given in config";
 
-    my $family_tree_data = FamilyTreeData->new();
+    my $family_tree_data = Ftree::FamilyTreeData->new();
     my $excel            = Spreadsheet::ParseExcel::Workbook->Parse($file_name)
       or die "Unable to parse file " . $file_name;
     foreach my $sheet ( @{ $excel->{Worksheet} } ) {
@@ -79,8 +79,8 @@ sub createFamilyTreeDataFromFile {
         }
     }
     if ( defined $config_->{photo_dir} ) {
-        Ftree::ExtendedSimonWardFormat::setPictureDirectory( $config_->{photo_dir} );
-        Ftree::ExtendedSimonWardFormat::fill_up_pictures($family_tree_data);
+        Ftree::DataParsers::ExtendedSimonWardFormat::setPictureDirectory( $config_->{photo_dir} );
+        Ftree::DataParsers::ExtendedSimonWardFormat::fill_up_pictures($family_tree_data);
     }
 
     return $family_tree_data;
@@ -101,9 +101,13 @@ sub convertCell {
 
         # next;
     }
-    $val = decode( "UTF-16BE", $val ) if ( $cell->{Code} eq 'ucs2' );
+    if (defined $val){
+    if ( defined $cell->{Code} && $cell->{Code} eq 'ucs2' ){
+    $val = decode( "UTF-16BE", $val );
+  }
     $val =~ s/^\s+//;
     $val =~ s/\s+$//;
+  }
     if ( $val eq '' ) {
         $rowtxt = "\t";
         next;
