@@ -20,14 +20,14 @@
 #
 #######################################################
 
-package GedcomFormat;
+package Ftree::DataParsers::GedcomFormat;
 use strict;
 use warnings;
-use version; our $VERSION = qv('2.3.31');
+use version; our $VERSION = qv('2.3.32');
 use Gedcom;
 use Ftree::DataParsers::FieldValidatorParser;
 use Ftree::FamilyTreeData;
-use CGI::Carp qw(fatalsToBrowser);
+# use CGI::Carp qw(fatalsToBrowser);
 use Encode qw(decode_utf8);
 
 my %genderTogedcomsex = (
@@ -58,7 +58,7 @@ sub createFamilyTreeDataFromFile {
   my $file_name = $config_->{file_name} or die "No file_name is given in config";
 
   my $ged = Gedcom->new(gedcom_file  => $file_name);
-  my $family_tree_data = FamilyTreeData->new();                        
+  my $family_tree_data = Ftree::FamilyTreeData->new();                        
   for my $i ($ged->individuals)
   {
     $family_tree_data->add_person({
