@@ -14,22 +14,22 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# For a copy of the GNU General Public License, visit 
+# For a copy of the GNU General Public License, visit
 # http://www.gnu.org or write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #
 #######################################################
 
 
-package SerializerFormat;
+package Ftree::DataParsers::SerializerFormat;
 use strict;
 use warnings;
-use version; our $VERSION = qv('2.3.31');
+use version; our $VERSION = qv('2.3.32');
 use Ftree::DataParsers::FieldValidatorParser;
 use Ftree::DataParsers::ExtendedSimonWardFormat; # for getting pictures. Temporal solution
 use Ftree::FamilyTreeData;
 use Storable;
-use CGI::Carp qw(fatalsToBrowser);
+# use CGI::Carp qw(fatalsToBrowser);
 
 sub createFamilyTreeDataFromFile {
   my ($config_) = @_;
@@ -37,10 +37,10 @@ sub createFamilyTreeDataFromFile {
 
   my $family_tree_data = Storable::retrieve($file_name);
   if(defined $config_->{photo_dir}) {
-    Ftree::ExtendedSimonWardFormat::setPictureDirectory($config_->{photo_dir});
-    Ftree::ExtendedSimonWardFormat::fill_up_pictures($family_tree_data);
+    Ftree::DataParsers::ExtendedSimonWardFormat::setPictureDirectory($config_->{photo_dir});
+    Ftree::DataParsers::ExtendedSimonWardFormat::fill_up_pictures($family_tree_data);
   }
-  
+
   return $family_tree_data;
 }
 
