@@ -14,17 +14,17 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# For a copy of the GNU General Public License, visit 
+# For a copy of the GNU General Public License, visit
 # http://www.gnu.org or write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #
 #######################################################
 
-package ExcelExporter;
+package Ftree::Exporters::ExcelExporter;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv('2.3.31');
+use version; our $VERSION = qv('2.3.32');
 use Spreadsheet::WriteExcel;
 
 sub export {
@@ -41,20 +41,20 @@ sub export {
   	if(defined $person) {
     my @person_row = ();
     push @person_row, $person->get_id();
-    
+
     if(defined $person->get_name()) {
-     push @person_row, ($person->get_name()->get_title(), 
+     push @person_row, ($person->get_name()->get_title(),
       $person->get_name()->get_prefix(), $person->get_name()->get_first_name(),
-      $person->get_name()->get_mid_name(), $person->get_name()->get_last_name(), 
+      $person->get_name()->get_mid_name(), $person->get_name()->get_last_name(),
       $person->get_name()->get_suffix(), $person->get_name()->get_nickname())
     }
     else {
     	push @person_row, (undef, undef, undef, undef, undef, undef, undef)
     }
-    push @person_row, (defined $person->get_father()) ? $person->get_father()->get_id() : undef; 
-    push @person_row, (defined $person->get_mother()) ? $person->get_mother()->get_id() : undef; 
+    push @person_row, (defined $person->get_father()) ? $person->get_father()->get_id() : undef;
+    push @person_row, (defined $person->get_mother()) ? $person->get_mother()->get_id() : undef;
     push @person_row, ($person->get_email(), $person->get_homepage());
-      
+
     my $date = "";
     if(defined $person->get_date_of_birth()) {
       my $date_of_birth = $person->get_date_of_birth();
@@ -63,8 +63,8 @@ sub export {
       $date .= defined $date_of_birth->year ? $date_of_birth->year : "";
     }
     push @person_row, $date;
-    
-    $date = "";  
+
+    $date = "";
     if(defined $person->get_date_of_death()) {
       my $date_of_death = $person->get_date_of_death();
       $date .= defined $date_of_death->day ? $date_of_death->day."/" : "";
@@ -72,22 +72,22 @@ sub export {
       $date .= defined $date_of_death->year ? $date_of_death->year : "";
     }
     push @person_row, $date;
-    push @person_row, ($person->get_gender(), $person->get_is_living(), 
+    push @person_row, ($person->get_gender(), $person->get_is_living(),
       getPlaceString($person->get_place_of_birth()), getPlaceString($person->get_place_of_death()));
-    
+
     my $cemetery = "";
     if (defined $person->get_cemetery()) {
       $cemetery .= '"' . $person->get_cemetery()->{country} .'"';
-      $cemetery .= defined $person->get_cemetery()->{city} ? ' "' . 
+      $cemetery .= defined $person->get_cemetery()->{city} ? ' "' .
         $person->get_cemetery->{city} . '"' : "";
-      $cemetery .= defined $person->get_cemetery()->{cemetery} ? ' "' . 
+      $cemetery .= defined $person->get_cemetery()->{cemetery} ? ' "' .
         $person->get_cemetery->{cemetery} . '"' : "";
     }
-    push @person_row, ($cemetery, defined $person->get_schools() ? 
-      join(',', @{$person->get_schools()}) : "", 
-      defined $person->get_jobs() ? join(',', @{$person->get_jobs()}) : "", 
+    push @person_row, ($cemetery, defined $person->get_schools() ?
+      join(',', @{$person->get_schools()}) : "",
+      defined $person->get_jobs() ? join(',', @{$person->get_jobs()}) : "",
       defined $person->get_work_places() ? join(',', @{$person->get_work_places()}) : "",
-      defined $person->get_places_of_living() ? 
+      defined $person->get_places_of_living() ?
         join(',', map {getPlaceString($_)} @{$person->get_places_of_living()} ) : "",
       $person->get_general() );
     $worksheet->write_row($row, 0, \@person_row);
@@ -103,6 +103,6 @@ sub getPlaceString {
       $place_string .= defined $place->{city} ? " \"$place->{city}\"" : "";
    }
    return $place_string;
-    
+
 }
 1;
