@@ -23,9 +23,9 @@
 package Ftree::Picture;
 use strict;
 use warnings;
-use version; our $VERSION = qv('2.3.31');
+use version; our $VERSION = qv('2.3.32');
 
-use Class::Std::Storable;
+use Class::Std::Fast::Storable;
 {
   my %file_name_of : ATTR(:name<file_name>);
   my %comment_of : ATTR(:name<comment>);
