@@ -14,7 +14,7 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# For a copy of the GNU General Public License, visit 
+# For a copy of the GNU General Public License, visit
 # http://www.gnu.org or write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #
@@ -26,13 +26,13 @@ use warnings;
 use lib "../config";
 
 package Ftree::SettingsFactory;
-use version; our $VERSION = qv('2.3.31');
+use version; our $VERSION = qv('2.3.32');
 
 sub importSettings{
-  my ( $type ) = @_;
+  my ( $type, $config_name ) = @_;
   if($type eq "perl") {
     require Ftree::PerlSettingsImporter;
-    return Ftree::PerlSettingsImporter::importSettings();
+    return Ftree::PerlSettingsImporter::importSettings($config_name);
   }
 }
 
